

## 📋 Before Merge Checklist

1. [ ] I have chosen a new version number with respect to [semver](https://semver.org/)
2. [ ] I have updated the version in these files consistently: *Cargo.toml*, *compact-calendar/Cargo.toml*, *opening-hours-syntax/Cargo.toml*, *python/Cargo.toml* and *pyproject.toml*
3. [ ] I have updated *CHANGELOG.md*
